# the Algmon Infra lib

## company intro

* https://algmon.com/

## **lib intro**

* https://algmon.com/docs/infra/intro

## lib source code

* github
*
* gitee
* https://gitee.com/algmon/public/tree/master/src/algmon-brain

## lib features

* be stable
* at scale
* in intelligent

## dependencies

*

## the license

* This package is released under the Apache License v2
